local addonName = ...
local core = LibStub("AceAddon-3.0"):GetAddon(addonName)
local module = core:NewModule(addonName.."Config", "AceConsole-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale(addonName)

local db
local optionsFrame

local name, title, notes = GetAddOnInfo(addonName)

local options = {
	name = title,
	-- handler = addon,
	type = "group",
	get = function(info) return db[info[#info]] end,
	set = function(info, v) db[info[#info]] = v end,
	args = {
		description = {
			type = "description",
			name = notes,
			order = 0,
		},
		general = {
			type = "group",
			name = L["General"],
			order = 1,
			inline = true,
			args = {
				delay = {
					type = "range",
					name = L["Delay time (seconds)"],
					desc = L["Set the delay time to join all gains in short periods of time (0 to disable)."],
					min = 0, max = 10, step = 0.25,
					order = 4,
					width = "full",
				},
			},
		},
		reputation = {
			type = "group",
			name = L["Reputations"],
			order = 2,
			inline = true,
			args = {
				reputationReplace = {
					type = "toggle",
					name = L["Replace Default Text"],
					descStyle = "inline",
					order = 1,
					width = "full",
				},
				colors = {
					type = "toggle",
					name = L["Change Reputation Colors"],
					desc = L["Change reputation colors in faction list."],
					descStyle = "inline",
					order = 2,
					width = "full",
					set = function(info, v) db[info[#info]] = v; core:updateColors() end,
				},
				changeReputationBar = {
					type = "toggle",
					name = L["Change Reputation Bar"],
					desc = L["Automatic change the faction on the reputation bar."],
					descStyle = "inline",
					order = 3,
					width = "full",
				},
			},
		},
		currency = {
			type = "group",
			name = L["Currencies"],
			order = 3,
			inline = true,
			args = {
				currencyReplace = {
					type = "toggle",
					name = L["Replace Default Text"],
					descStyle = "inline",
					order = 1,
					width = "full",
				},
			},
		},
		reset = {
			type = "execute",
			name = L["Reset Options"],
			order = -1,
			func = function() core.db:ResetProfile() end,
			confirm = true,
			confirmText = L["Do you really want to reset the options?"],
		},
	},
}

function module:OnInitialize()
	db = core.db.profile

	-- options.args.profiles = LibStub("AceDBOptions-3.0"):GetOptionsTable(core.db)

	LibStub("AceConfig-3.0"):RegisterOptionsTable(addonName, options)
	optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions(addonName, addonName)

end


